@@ -7,14 +7,26 @@ are lazy evaluated, they can be built from templates
 """
 import abc
 import logging
-from math import ceil
 
 from ploomber.products.Metadata import Metadata
 
 
+def _prepare_metadata(metadata):
+    return metadata
+
+
 class Product(abc.ABC):
     """
     Abstract class for all Products
+
+    Attributes
+    ----------
+    prepare_metadata : callable
+        A hook to execute before saving metadata, should include a "metadata"
+        parameter and might include "product". "metadata" will be a
+        dictionary with the metadata to save, it is not recommended to change
+        any of the existing keys but additional key-value pairs might be
+        included
     """
 
     def __init__(self, identifier):
@@ -32,7 +44,10 @@ class Product(abc.ABC):
         self._outdated_code_dependency_status = None
         self.metadata = Metadata(self)
 
+        self.prepare_metadata = _prepare_metadata
+
     def _save_metadata(self, source_code):
+        # this is called by task in the exec_status setter
         self.metadata.update(source_code)
 
     @property
@@ -114,7 +129,7 @@ class Product(abc.ABC):
             timestamp or if an upstream product is outdated
             """
             if (self.metadata.timestamp is None
-               or up_prod.metadata.timestamp is None):
+                    or up_prod.metadata.timestamp is None):
                 return True
             else:
                 return ((up_prod.metadata.timestamp > self.metadata.timestamp)
@@ -174,24 +189,8 @@ class Product(abc.ABC):
         return str(self._identifier)
 
     def __repr__(self):
-        return '{}({})'.format(type(self).__name__, self._identifier.safe)
-
-    def _short_repr(self):
-        s = str(self._identifier)
-
-        if len(s) > 20:
-            s_short = ''
-
-            t = ceil(len(s) / 20)
-
-            for i in range(t):
-                s_short += s[(20 * i):(20 * (i + 1))] + '\n'
-        else:
-            s_short = s
-
-        return s_short
-
-    # __getstate__ and __setstate__ are needed to make this picklable
+        return '{}({})'.format(type(self).__name__,
+                               self._identifier.best_str(shorten=True))
 
     def __getstate__(self):
         state = self.__dict__.copy()
