@@ -6,8 +6,9 @@ from ploomber.tasks.TaskFactory import TaskFactory
 from ploomber.tasks.sql import (SQLScript, SQLDump, SQLTransfer,
                                 SQLUpload, PostgresCopyFrom)
 from ploomber.tasks.notebook import NotebookRunner
+from ploomber.tasks.aws import UploadToS3
 
 __all__ = ['PythonCallable', 'ShellScript', 'TaskFactory',
            'Task', 'SQLScript', 'SQLDump', 'SQLTransfer', 'SQLUpload',
            'PostgresCopyFrom', 'NotebookRunner', 'DownloadFromURL',
-           'Link', 'Input']
+           'Link', 'Input', 'UploadToS3']
